## eff-uper

B1リーグのバスケットボール選手の貢献度を評価するために使われる数値(2016年から2021年度)
「EFF」と「uPER」を年度ごとに比較するPython Package
[B1リーグスタッツ](https://www.bleague.jp/stats/)
上記のサイトを参考にしています。

### Example of use

```
pip install eff-uper
eff-uper 2021
```
Please enter '2016, 2017, 2018, 2019, 2020, or 2021'.


![output](./pic01.png)
The horizontal axis is EFF and the vertical axis is uPER.